#  tests for pivottablejs-airgap-2.7.0-py37h6ffa863_0 (this is a generated file);
print('===== testing package: pivottablejs-airgap-2.7.0-py37h6ffa863_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import pivottablejs

print('pivottablejs.__version__: %s' % pivottablejs.__version__)
assert pivottablejs.__version__ == '2.7.0'
#  --- run_test.py (end) ---

print('===== pivottablejs-airgap-2.7.0-py37h6ffa863_0 OK =====');
print("import: 'pivottablejs'")
import pivottablejs

